import { APIClient } from "./ApiClient";

export interface InboxEntry {
  id: number;
  file_id: number;
  user_id: number;
  movement_id?: number;
  time: number;
  label?: string;
  amount?: number;
  time_create: number;
  time_update: number;
}

export interface InboxEntryUpdate {
  file_id: number;
  movement_id?: number;
  time: number;
  label?: string;
  amount?: number;
}

export class InboxApi {
  /**
   * Create a new inbox entry
   */
  static async Create(entry: InboxEntryUpdate): Promise<void> {
    await APIClient.exec({
      uri: `/inbox`,
      method: "POST",
      jsonData: entry,
    });
  }

  /**
   * Get the list of inbox entries
   */
  static async GetList(includeAttached: boolean): Promise<InboxEntry[]> {
    return (
      await APIClient.exec({
        uri: `/inbox?include_attached=${includeAttached ? "true" : "false"}`,
        method: "GET",
      })
    ).data;
  }
}
